/*
 * heim_err.h:
 * This file is automatically generated; please do not edit it.
 */

#include <et/com_err.h>

#define HEIM_ERR_LOG_PARSE                       (-1980176640L)
#define HEIM_ERR_V4_PRINC_NO_CONV                (-1980176639L)
#define HEIM_ERR_SALTTYPE_NOSUPP                 (-1980176638L)
#define HEIM_ERR_NOHOST                          (-1980176637L)
#define HEIM_ERR_OPNOTSUPP                       (-1980176636L)
#define HEIM_ERR_EOF                             (-1980176635L)
#define HEIM_ERR_BAD_MKEY                        (-1980176634L)
#define HEIM_ERR_SERVICE_NOMATCH                 (-1980176633L)
#define HEIM_ERR_NOT_SEEKABLE                    (-1980176632L)
#define HEIM_ERR_TOO_BIG                         (-1980176631L)
#define HEIM_ERR_BAD_HDBENT_ENCODING             (-1980176630L)
#define HEIM_ERR_RANDOM_OFFLINE                  (-1980176629L)
#define HEIM_PKINIT_NO_CERTIFICATE               (-1980176576L)
#define HEIM_PKINIT_NO_PRIVATE_KEY               (-1980176575L)
#define HEIM_PKINIT_NO_VALID_CA                  (-1980176574L)
#define HEIM_PKINIT_CERTIFICATE_INVALID          (-1980176573L)
#define HEIM_PKINIT_PRIVATE_KEY_INVALID          (-1980176572L)
#define HEIM_EAI_UNKNOWN                         (-1980176512L)
#define HEIM_EAI_ADDRFAMILY                      (-1980176511L)
#define HEIM_EAI_AGAIN                           (-1980176510L)
#define HEIM_EAI_BADFLAGS                        (-1980176509L)
#define HEIM_EAI_FAIL                            (-1980176508L)
#define HEIM_EAI_FAMILY                          (-1980176507L)
#define HEIM_EAI_MEMORY                          (-1980176506L)
#define HEIM_EAI_NODATA                          (-1980176505L)
#define HEIM_EAI_NONAME                          (-1980176504L)
#define HEIM_EAI_SERVICE                         (-1980176503L)
#define HEIM_EAI_SOCKTYPE                        (-1980176502L)
#define HEIM_EAI_SYSTEM                          (-1980176501L)
#define HEIM_NET_CONN_REFUSED                    (-1980176448L)
extern const struct error_table et_heim_error_table;
extern void initialize_heim_error_table(void);

/* For compatibility with Heimdal */
extern void initialize_heim_error_table_r(struct et_list **list);

#define ERROR_TABLE_BASE_heim (-1980176640L)

/* for compatibility with older versions... */
#define init_heim_err_tbl initialize_heim_error_table
#define heim_err_base ERROR_TABLE_BASE_heim
