/*
 * gkrb5_err.h:
 * This file is automatically generated; please do not edit it.
 */

#include <et/com_err.h>

#define GSS_KRB5_S_G_BAD_SERVICE_NAME            (35224064L)
#define GSS_KRB5_S_G_BAD_STRING_UID              (35224065L)
#define GSS_KRB5_S_G_NOUSER                      (35224066L)
#define GSS_KRB5_S_G_VALIDATE_FAILED             (35224067L)
#define GSS_KRB5_S_G_BUFFER_ALLOC                (35224068L)
#define GSS_KRB5_S_G_BAD_MSG_CTX                 (35224069L)
#define GSS_KRB5_S_G_WRONG_SIZE                  (35224070L)
#define GSS_KRB5_S_G_BAD_USAGE                   (35224071L)
#define GSS_KRB5_S_G_UNKNOWN_QOP                 (35224072L)
#define GSS_KRB5_S_KG_CCACHE_NOMATCH             (35224192L)
#define GSS_KRB5_S_KG_KEYTAB_NOMATCH             (35224193L)
#define GSS_KRB5_S_KG_TGT_MISSING                (35224194L)
#define GSS_KRB5_S_KG_NO_SUBKEY                  (35224195L)
#define GSS_KRB5_S_KG_CONTEXT_ESTABLISHED        (35224196L)
#define GSS_KRB5_S_KG_BAD_SIGN_TYPE              (35224197L)
#define GSS_KRB5_S_KG_BAD_LENGTH                 (35224198L)
#define GSS_KRB5_S_KG_CTX_INCOMPLETE             (35224199L)
#define GSS_KRB5_S_KG_INPUT_TOO_LONG             (35224200L)
extern const struct error_table et_gk5_error_table;
extern void initialize_gk5_error_table(void);

/* For compatibility with Heimdal */
extern void initialize_gk5_error_table_r(struct et_list **list);

#define ERROR_TABLE_BASE_gk5 (35224064L)

/* for compatibility with older versions... */
#define init_gk5_err_tbl initialize_gk5_error_table
#define gk5_err_base ERROR_TABLE_BASE_gk5
