/*
 * asn1_err.h:
 * This file is automatically generated; please do not edit it.
 */

#include <et/com_err.h>

#define ASN1_BAD_TIMEFORMAT                      (1859794432L)
#define ASN1_MISSING_FIELD                       (1859794433L)
#define ASN1_MISPLACED_FIELD                     (1859794434L)
#define ASN1_TYPE_MISMATCH                       (1859794435L)
#define ASN1_OVERFLOW                            (1859794436L)
#define ASN1_OVERRUN                             (1859794437L)
#define ASN1_BAD_ID                              (1859794438L)
#define ASN1_BAD_LENGTH                          (1859794439L)
#define ASN1_BAD_FORMAT                          (1859794440L)
#define ASN1_PARSE_ERROR                         (1859794441L)
#define ASN1_EXTRA_DATA                          (1859794442L)
#define ASN1_BAD_CHARACTER                       (1859794443L)
#define ASN1_MIN_CONSTRAINT                      (1859794444L)
#define ASN1_MAX_CONSTRAINT                      (1859794445L)
#define ASN1_EXACT_CONSTRAINT                    (1859794446L)
#define ASN1_INDEF_OVERRUN                       (1859794447L)
#define ASN1_INDEF_UNDERRUN                      (1859794448L)
#define ASN1_GOT_BER                             (1859794449L)
#define ASN1_INDEF_EXTRA_DATA                    (1859794450L)
extern const struct error_table et_asn1_error_table;
extern void initialize_asn1_error_table(void);

/* For compatibility with Heimdal */
extern void initialize_asn1_error_table_r(struct et_list **list);

#define ERROR_TABLE_BASE_asn1 (1859794432L)

/* for compatibility with older versions... */
#define init_asn1_err_tbl initialize_asn1_error_table
#define asn1_err_base ERROR_TABLE_BASE_asn1
