/*
 * wind_err.h:
 * This file is automatically generated; please do not edit it.
 */

#include <et/com_err.h>

#define WIND_ERR_NONE                            (-969269760L)
#define WIND_ERR_NO_PROFILE                      (-969269759L)
#define WIND_ERR_OVERRUN                         (-969269758L)
#define WIND_ERR_UNDERUN                         (-969269757L)
#define WIND_ERR_LENGTH_NOT_MOD2                 (-969269756L)
#define WIND_ERR_LENGTH_NOT_MOD4                 (-969269755L)
#define WIND_ERR_INVALID_UTF8                    (-969269754L)
#define WIND_ERR_INVALID_UTF16                   (-969269753L)
#define WIND_ERR_INVALID_UTF32                   (-969269752L)
#define WIND_ERR_NO_BOM                          (-969269751L)
#define WIND_ERR_NOT_UTF16                       (-969269750L)
extern const struct error_table et_wind_error_table;
extern void initialize_wind_error_table(void);

/* For compatibility with Heimdal */
extern void initialize_wind_error_table_r(struct et_list **list);

#define ERROR_TABLE_BASE_wind (-969269760L)

/* for compatibility with older versions... */
#define init_wind_err_tbl initialize_wind_error_table
#define wind_err_base ERROR_TABLE_BASE_wind
