/*
 * hx509_err.h:
 * This file is automatically generated; please do not edit it.
 */

#include <et/com_err.h>

#define HX509_BAD_TIMEFORMAT                     (569856L)
#define HX509_EXTENSION_NOT_FOUND                (569857L)
#define HX509_NO_PATH                            (569858L)
#define HX509_PARENT_NOT_CA                      (569859L)
#define HX509_CA_PATH_TOO_DEEP                   (569860L)
#define HX509_SIG_ALG_NO_SUPPORTED               (569861L)
#define HX509_SIG_ALG_DONT_MATCH_KEY_ALG         (569862L)
#define HX509_CERT_USED_BEFORE_TIME              (569863L)
#define HX509_CERT_USED_AFTER_TIME               (569864L)
#define HX509_PRIVATE_KEY_MISSING                (569865L)
#define HX509_ALG_NOT_SUPP                       (569866L)
#define HX509_ISSUER_NOT_FOUND                   (569867L)
#define HX509_VERIFY_CONSTRAINTS                 (569868L)
#define HX509_RANGE                              (569869L)
#define HX509_NAME_CONSTRAINT_ERROR              (569870L)
#define HX509_PATH_TOO_LONG                      (569871L)
#define HX509_KU_CERT_MISSING                    (569872L)
#define HX509_CERT_NOT_FOUND                     (569873L)
#define HX509_UNKNOWN_LOCK_COMMAND               (569874L)
#define HX509_PARENT_IS_CA                       (569875L)
#define HX509_EXTRA_DATA_AFTER_STRUCTURE         (569876L)
#define HX509_PROXY_CERT_INVALID                 (569877L)
#define HX509_PROXY_CERT_NAME_WRONG              (569878L)
#define HX509_NAME_MALFORMED                     (569879L)
#define HX509_CERTIFICATE_MALFORMED              (569880L)
#define HX509_CERTIFICATE_MISSING_EKU            (569881L)
#define HX509_PROXY_CERTIFICATE_NOT_CANONICALIZED (569882L)
#define HX509_CMS_FAILED_CREATE_SIGATURE         (569888L)
#define HX509_CMS_MISSING_SIGNER_DATA            (569889L)
#define HX509_CMS_SIGNER_NOT_FOUND               (569890L)
#define HX509_CMS_NO_DATA_AVAILABLE              (569891L)
#define HX509_CMS_INVALID_DATA                   (569892L)
#define HX509_CMS_PADDING_ERROR                  (569893L)
#define HX509_CMS_NO_RECIPIENT_CERTIFICATE       (569894L)
#define HX509_CMS_DATA_OID_MISMATCH              (569895L)
#define HX509_CRYPTO_INTERNAL_ERROR              (569920L)
#define HX509_CRYPTO_EXTERNAL_ERROR              (569921L)
#define HX509_CRYPTO_SIGNATURE_MISSING           (569922L)
#define HX509_CRYPTO_BAD_SIGNATURE               (569923L)
#define HX509_CRYPTO_SIG_NO_CONF                 (569924L)
#define HX509_CRYPTO_SIG_INVALID_FORMAT          (569925L)
#define HX509_CRYPTO_OID_MISMATCH                (569926L)
#define HX509_CRYPTO_NO_PROMPTER                 (569927L)
#define HX509_CRYPTO_SIGNATURE_WITHOUT_SIGNER    (569928L)
#define HX509_CRYPTO_RSA_PUBLIC_ENCRYPT          (569929L)
#define HX509_CRYPTO_RSA_PRIVATE_ENCRYPT         (569930L)
#define HX509_CRYPTO_RSA_PUBLIC_DECRYPT          (569931L)
#define HX509_CRYPTO_RSA_PRIVATE_DECRYPT         (569932L)
#define HX509_CRYPTO_ALGORITHM_BEST_BEFORE       (569933L)
#define HX509_CRYPTO_KEY_FORMAT_UNSUPPORTED      (569934L)
#define HX509_CRL_USED_BEFORE_TIME               (569952L)
#define HX509_CRL_USED_AFTER_TIME                (569953L)
#define HX509_CRL_INVALID_FORMAT                 (569954L)
#define HX509_CERT_REVOKED                       (569955L)
#define HX509_REVOKE_STATUS_MISSING              (569956L)
#define HX509_CRL_UNKNOWN_EXTENSION              (569957L)
#define HX509_REVOKE_WRONG_DATA                  (569958L)
#define HX509_REVOKE_NOT_SAME_PARENT             (569959L)
#define HX509_CERT_NOT_IN_OCSP                   (569960L)
#define HX509_LOCAL_ATTRIBUTE_MISSING            (569964L)
#define HX509_PARSING_KEY_FAILED                 (569965L)
#define HX509_UNSUPPORTED_OPERATION              (569966L)
#define HX509_UNIMPLEMENTED_OPERATION            (569967L)
#define HX509_PARSING_NAME_FAILED                (569968L)
#define HX509_PKCS11_NO_SLOT                     (569984L)
#define HX509_PKCS11_NO_TOKEN                    (569985L)
#define HX509_PKCS11_NO_MECH                     (569986L)
#define HX509_PKCS11_TOKEN_CONFUSED              (569987L)
#define HX509_PKCS11_OPEN_SESSION                (569988L)
#define HX509_PKCS11_LOGIN                       (569989L)
#define HX509_PKCS11_LOAD                        (569990L)
#define HX509_PKCS11_PIN_INCORRECT               (569991L)
#define HX509_PKCS11_PIN_LOCKED                  (569992L)
#define HX509_PKCS11_PIN_NOT_INITIALIZED         (569993L)
#define HX509_PKCS11_PIN_EXPIRED                 (569994L)
extern const struct error_table et_hx_error_table;
extern void initialize_hx_error_table(void);

/* For compatibility with Heimdal */
extern void initialize_hx_error_table_r(struct et_list **list);

#define ERROR_TABLE_BASE_hx (569856L)

/* for compatibility with older versions... */
#define init_hx_err_tbl initialize_hx_error_table
#define hx_err_base ERROR_TABLE_BASE_hx
