/*
 * ntlm_err.h:
 * This file is automatically generated; please do not edit it.
 */

#include <et/com_err.h>

#define HNTLM_ERR_DECODE                         (-1561745664L)
#define HNTLM_ERR_INVALID_LENGTH                 (-1561745663L)
#define HNTLM_ERR_CRYPTO                         (-1561745662L)
#define HNTLM_ERR_RAND                           (-1561745661L)
#define HNTLM_ERR_AUTH                           (-1561745660L)
#define HNTLM_ERR_TIME_SKEW                      (-1561745659L)
#define HNTLM_ERR_OEM                            (-1561745658L)
#define HNTLM_ERR_MISSING_NAME_SEPARATOR         (-1561745657L)
#define HNTLM_ERR_MISSING_BUFFER                 (-1561745656L)
#define HNTLM_ERR_INVALID_APOP                   (-1561745655L)
#define HNTLM_ERR_INVALID_CRAM_MD5               (-1561745654L)
#define HNTLM_ERR_INVALID_DIGEST_MD5             (-1561745653L)
#define HNTLM_ERR_INVALID_DIGEST_MD5_RSPAUTH     (-1561745652L)
#define HNTLM_ERR_INVALID_CHANNEL_BINDINGS       (-1561745651L)
#define HNTLM_ERR_INVALID_MIC                    (-1561745650L)
#define HNTLM_ERR_INVALID_SESSIONKEY             (-1561745649L)
#define HNTLM_ERR_NOT_CONFIGURED                 (-1561745600L)
#define HNTLM_ERR_INVALID_CHALLANGE              (-1561745599L)
#define HNTLM_ERR_INVALID_NT_RESPONSE            (-1561745598L)
#define HNTLM_ERR_INVALID_SESSION_KEY            (-1561745597L)
#define HNTLM_ERR_INVALID_NO_GUEST               (-1561745596L)
#define HNTLM_ERR_NO_NETR_CONFIGURED             (-1561745595L)
#define HSCRAM_ERR_INVALID_MESSAGE               (-1561745536L)
#define HSCRAM_ERR_INVALID_PROOF                 (-1561745535L)
#define HSCRAM_ERR_INVALID_ROLE                  (-1561745534L)
extern const struct error_table et_ntlm_error_table;
extern void initialize_ntlm_error_table(void);

/* For compatibility with Heimdal */
extern void initialize_ntlm_error_table_r(struct et_list **list);

#define ERROR_TABLE_BASE_ntlm (-1561745664L)

/* for compatibility with older versions... */
#define init_ntlm_err_tbl initialize_ntlm_error_table
#define ntlm_err_base ERROR_TABLE_BASE_ntlm
